# """This module includes methods to fine-tune the parameters of a sweep.
#
# The grid search provided by [ParameterGrid](grid.sdk.sweeps.grid_search_strategy.ParameterGrid)
# exhaustively generates candidates from a grid of parameter values specified
# with the param_grid parameter. For instance, the following param_grid:
#
#     param_grid = [
#         {'C': [1, 10, 100, 1000], 'kernel': ['linear']},
#         {'C': [1, 10, 100, 1000], 'gamma': [0.001, 0.0001], 'kernel': ['rbf']},
#     ]
#
# specifies that two grids should be explored: one with a linear kernel and C
# values in `[1, 10, 100, 1000]`, and the second one with an RBF kernel, and the
# cross-product of C values ranging in `[1, 10, 100, 1000]` and gamma values
# in `[0.001, 0.0001]`.
# """
from grid.sdk.sweeps.grid_search_strategy import ParameterGrid, ParameterSampler

__all__ = ["ParameterGrid", "ParameterSampler"]



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import tensorboard_service_pb2 as grid_dot_v1_dot_tensorboard__service__pb2


class TensorboardServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.CreateTensorboard = channel.unary_unary(
        '/grid.v1.TensorboardService/CreateTensorboard',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.FromString,
        )
    self.GetTensorboard = channel.unary_unary(
        '/grid.v1.TensorboardService/GetTensorboard',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.FromString,
        )
    self.ListTensorboards = channel.unary_unary(
        '/grid.v1.TensorboardService/ListTensorboards',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.FromString,
        )
    self.UpdateTensorboard = channel.unary_unary(
        '/grid.v1.TensorboardService/UpdateTensorboard',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.FromString,
        )
    self.UpdateTensorboardStatus = channel.unary_unary(
        '/grid.v1.TensorboardService/UpdateTensorboardStatus',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.FromString,
        )
    self.DeleteTensorboard = channel.unary_unary(
        '/grid.v1.TensorboardService/DeleteTensorboard',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.FromString,
        )
    self.WatchTensorboards = channel.unary_stream(
        '/grid.v1.TensorboardService/WatchTensorboards',
        request_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.FromString,
        )


class TensorboardServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def CreateTensorboard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTensorboard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListTensorboards(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateTensorboard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateTensorboardStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteTensorboard(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchTensorboards(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TensorboardServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'CreateTensorboard': grpc.unary_unary_rpc_method_handler(
          servicer.CreateTensorboard,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.CreateTensorboardResponse.SerializeToString,
      ),
      'GetTensorboard': grpc.unary_unary_rpc_method_handler(
          servicer.GetTensorboard,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.GetTensorboardResponse.SerializeToString,
      ),
      'ListTensorboards': grpc.unary_unary_rpc_method_handler(
          servicer.ListTensorboards,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.ListTensorboardsResponse.SerializeToString,
      ),
      'UpdateTensorboard': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateTensorboard,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardResponse.SerializeToString,
      ),
      'UpdateTensorboardStatus': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateTensorboardStatus,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.UpdateTensorboardStatusResponse.SerializeToString,
      ),
      'DeleteTensorboard': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteTensorboard,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.DeleteTensorboardResponse.SerializeToString,
      ),
      'WatchTensorboards': grpc.unary_stream_rpc_method_handler(
          servicer.WatchTensorboards,
          request_deserializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsRequest.FromString,
          response_serializer=grid_dot_v1_dot_tensorboard__service__pb2.WatchTensorboardsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.TensorboardService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from dataclasses import dataclass

from grid.sdk import env
from grid.sdk._gql.queries import get_user_basic_info


@dataclass(frozen=True)
class User:
    """Representation of generic information about the user in grid.

    Attributes
    ----------
    user_id
        The internal grid ID assigned to the user.
    username
        The normal 'name' which the user is associated with.
    first_name
        The real-life first name of the user.
    last_name
        The real-life last name of the user.
    """
    user_id: str
    username: str
    first_name: str
    last_name: str


@dataclass(frozen=True)
class SDKUser(User):
    email: str
    is_verified: bool
    is_blocked: bool
    completed_signup: bool

    @classmethod
    def from_logged_in_user(cls) -> "SDKUser":
        resp = get_user_basic_info()
        if not resp["isVerified"]:
            raise PermissionError(
                f"User account not yet verified. Verify your "
                f"account at {env.GRID_URL}/#/verification"
            )
        if not resp["completedSignup"]:
            raise PermissionError(
                f"You haven't yet completed registration. Please complete "
                f"registration at {env.GRID_URL}/#/registration"
            )
        if resp["isBlocked"]:
            raise PermissionError(
                f"Your account with username `{resp['username']}` has been "
                f"suspended. Please reach out to support at support@grid.ai"
            )

        return cls(
            user_id=resp["userId"],
            username=resp["username"],
            first_name=resp["firstName"],
            last_name=resp["lastName"],
            email=resp["email"],
            is_verified=resp["isVerified"],
            is_blocked=resp["isBlocked"],
            completed_signup=resp["completedSignup"],
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import cluster_pb2 as grid_dot_v1_dot_cluster__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from grid.protos.grid.v1 import logs_pb2 as grid_dot_v1_dot_logs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/cluster_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dgrid/v1/cluster_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x15grid/v1/cluster.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12grid/v1/logs.proto\"B\n\x14\x43reateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x43reateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"#\n\x11GetClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"@\n\x12GetClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\x8d\x04\n\x13ListClustersRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x94\x01\n\x14ListClustersResponse\x12*\n\x07\x63luster\x18\x01 \x03(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"B\n\x14UpdateClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15UpdateClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"H\n\x1aUpdateClusterStatusRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"I\n\x1bUpdateClusterStatusResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"B\n\x14\x44\x65leteClusterRequest\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"C\n\x15\x44\x65leteClusterResponse\x12*\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xe7\x03\n\x14WatchClustersRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\x12\x30\n\x08phase_in\x18\x05 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x07phaseIn\x12\x37\n\x0cphase_not_in\x18\x06 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\nphaseNotIn\x12?\n\x10\x64\x65sired_state_in\x18\x07 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x0e\x64\x65siredStateIn\x12\x46\n\x14\x64\x65sired_state_not_in\x18\x08 \x03(\x0e\x32\x15.grid.v1.ClusterStateR\x11\x64\x65siredStateNotIn\x12<\n\x0f\x63luster_type_in\x18\t \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\rclusterTypeIn\x12\x43\n\x13\x63luster_type_not_in\x18\n \x03(\x0e\x32\x14.grid.v1.ClusterTypeR\x10\x63lusterTypeNotIn\"\x96\x01\n\x15WatchClustersResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12*\n\x07\x63luster\x18\x03 \x01(\x0b\x32\x10.grid.v1.ClusterR\x07\x63luster\"\xd4\x01\n\x17QueryClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\"G\n\x18QueryClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries\"\x92\x01\n\x16TailClusterLogsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x43\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\"F\n\x17TailClusterLogsResponse\x12+\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x11.grid.v1.LogEntryR\x07\x65ntries2\x83\x06\n\x0e\x43lusterService\x12P\n\rCreateCluster\x12\x1d.grid.v1.CreateClusterRequest\x1a\x1e.grid.v1.CreateClusterResponse\"\x00\x12G\n\nGetCluster\x12\x1a.grid.v1.GetClusterRequest\x1a\x1b.grid.v1.GetClusterResponse\"\x00\x12M\n\x0cListClusters\x12\x1c.grid.v1.ListClustersRequest\x1a\x1d.grid.v1.ListClustersResponse\"\x00\x12P\n\rUpdateCluster\x12\x1d.grid.v1.UpdateClusterRequest\x1a\x1e.grid.v1.UpdateClusterResponse\"\x00\x12`\n\x13UpdateClusterStatus\x12#.grid.v1.UpdateClusterStatusRequest\x1a$.grid.v1.UpdateClusterStatusResponse\x12P\n\rDeleteCluster\x12\x1d.grid.v1.DeleteClusterRequest\x1a\x1e.grid.v1.DeleteClusterResponse\"\x00\x12P\n\rWatchClusters\x12\x1d.grid.v1.WatchClustersRequest\x1a\x1e.grid.v1.WatchClustersResponse0\x01\x12W\n\x10QueryClusterLogs\x12 .grid.v1.QueryClusterLogsRequest\x1a!.grid.v1.QueryClusterLogsResponse\x12V\n\x0fTailClusterLogs\x12\x1f.grid.v1.TailClusterLogsRequest\x1a .grid.v1.TailClusterLogsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_cluster__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,grid_dot_v1_dot_logs__pb2.DESCRIPTOR,])




_CREATECLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateClusterRequest',
  full_name='grid.v1.CreateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.CreateClusterRequest.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=259,
)


_CREATECLUSTERRESPONSE = _descriptor.Descriptor(
  name='CreateClusterResponse',
  full_name='grid.v1.CreateClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.CreateClusterResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=328,
)


_GETCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetClusterRequest',
  full_name='grid.v1.GetClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetClusterRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=365,
)


_GETCLUSTERRESPONSE = _descriptor.Descriptor(
  name='GetClusterResponse',
  full_name='grid.v1.GetClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.GetClusterResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=431,
)


_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListClustersRequest',
  full_name='grid.v1.ListClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListClustersRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListClustersRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListClustersRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ListClustersRequest.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.ListClustersRequest.phase_in', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.ListClustersRequest.phase_not_in', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state_in', full_name='grid.v1.ListClustersRequest.desired_state_in', index=6,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredStateIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state_not_in', full_name='grid.v1.ListClustersRequest.desired_state_not_in', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredStateNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type_in', full_name='grid.v1.ListClustersRequest.cluster_type_in', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterTypeIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type_not_in', full_name='grid.v1.ListClustersRequest.cluster_type_not_in', index=9,
      number=10, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterTypeNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=959,
)


_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListClustersResponse',
  full_name='grid.v1.ListClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.ListClustersResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListClustersResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListClustersResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1110,
)


_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateClusterRequest',
  full_name='grid.v1.UpdateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.UpdateClusterRequest.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1178,
)


_UPDATECLUSTERRESPONSE = _descriptor.Descriptor(
  name='UpdateClusterResponse',
  full_name='grid.v1.UpdateClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.UpdateClusterResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1247,
)


_UPDATECLUSTERSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateClusterStatusRequest',
  full_name='grid.v1.UpdateClusterStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.UpdateClusterStatusRequest.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1321,
)


_UPDATECLUSTERSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateClusterStatusResponse',
  full_name='grid.v1.UpdateClusterStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.UpdateClusterStatusResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1396,
)


_DELETECLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterRequest',
  full_name='grid.v1.DeleteClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.DeleteClusterRequest.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1398,
  serialized_end=1464,
)


_DELETECLUSTERRESPONSE = _descriptor.Descriptor(
  name='DeleteClusterResponse',
  full_name='grid.v1.DeleteClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.DeleteClusterResponse.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1466,
  serialized_end=1533,
)


_WATCHCLUSTERSREQUEST = _descriptor.Descriptor(
  name='WatchClustersRequest',
  full_name='grid.v1.WatchClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchClustersRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchClustersRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.WatchClustersRequest.user_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_in', full_name='grid.v1.WatchClustersRequest.phase_in', index=3,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_not_in', full_name='grid.v1.WatchClustersRequest.phase_not_in', index=4,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='phaseNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state_in', full_name='grid.v1.WatchClustersRequest.desired_state_in', index=5,
      number=7, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredStateIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state_not_in', full_name='grid.v1.WatchClustersRequest.desired_state_not_in', index=6,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredStateNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type_in', full_name='grid.v1.WatchClustersRequest.cluster_type_in', index=7,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterTypeIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_type_not_in', full_name='grid.v1.WatchClustersRequest.cluster_type_not_in', index=8,
      number=10, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterTypeNotIn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1536,
  serialized_end=2023,
)


_WATCHCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='WatchClustersResponse',
  full_name='grid.v1.WatchClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchClustersResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchClustersResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='grid.v1.WatchClustersResponse.cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2176,
)


_QUERYCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='QueryClusterLogsRequest',
  full_name='grid.v1.QueryClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.QueryClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.QueryClusterLogsRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.QueryClusterLogsRequest.start_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='grid.v1.QueryClusterLogsRequest.end_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2179,
  serialized_end=2391,
)


_QUERYCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
  name='QueryClusterLogsResponse',
  full_name='grid.v1.QueryClusterLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='grid.v1.QueryClusterLogsResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2393,
  serialized_end=2464,
)


_TAILCLUSTERLOGSREQUEST = _descriptor.Descriptor(
  name='TailClusterLogsRequest',
  full_name='grid.v1.TailClusterLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.TailClusterLogsRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.TailClusterLogsRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.TailClusterLogsRequest.start_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2467,
  serialized_end=2613,
)


_TAILCLUSTERLOGSRESPONSE = _descriptor.Descriptor(
  name='TailClusterLogsResponse',
  full_name='grid.v1.TailClusterLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='grid.v1.TailClusterLogsResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2615,
  serialized_end=2685,
)

_CREATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_CREATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_GETCLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_LISTCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_LISTCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_UPDATECLUSTERSTATUSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERREQUEST.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_DELETECLUSTERRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_WATCHCLUSTERSREQUEST.fields_by_name['phase_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['phase_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['desired_state_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERSTATE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSREQUEST.fields_by_name['cluster_type_not_in'].enum_type = grid_dot_v1_dot_cluster__pb2._CLUSTERTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHCLUSTERSRESPONSE.fields_by_name['cluster'].message_type = grid_dot_v1_dot_cluster__pb2._CLUSTER
_QUERYCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUERYCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
_TAILCLUSTERLOGSREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAILCLUSTERLOGSRESPONSE.fields_by_name['entries'].message_type = grid_dot_v1_dot_logs__pb2._LOGENTRY
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateClusterResponse'] = _CREATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetClusterResponse'] = _GETCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterResponse'] = _UPDATECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterStatusRequest'] = _UPDATECLUSTERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateClusterStatusResponse'] = _UPDATECLUSTERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterResponse'] = _DELETECLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['WatchClustersRequest'] = _WATCHCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['WatchClustersResponse'] = _WATCHCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryClusterLogsRequest'] = _QUERYCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['QueryClusterLogsResponse'] = _QUERYCLUSTERLOGSRESPONSE
DESCRIPTOR.message_types_by_name['TailClusterLogsRequest'] = _TAILCLUSTERLOGSREQUEST
DESCRIPTOR.message_types_by_name['TailClusterLogsResponse'] = _TAILCLUSTERLOGSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType('CreateClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterRequest)
  })
_sym_db.RegisterMessage(CreateClusterRequest)

CreateClusterResponse = _reflection.GeneratedProtocolMessageType('CreateClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateClusterResponse)
  })
_sym_db.RegisterMessage(CreateClusterResponse)

GetClusterRequest = _reflection.GeneratedProtocolMessageType('GetClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetClusterRequest)
  })
_sym_db.RegisterMessage(GetClusterRequest)

GetClusterResponse = _reflection.GeneratedProtocolMessageType('GetClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetClusterResponse)
  })
_sym_db.RegisterMessage(GetClusterResponse)

ListClustersRequest = _reflection.GeneratedProtocolMessageType('ListClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListClustersRequest)
  })
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType('ListClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListClustersResponse)
  })
_sym_db.RegisterMessage(ListClustersResponse)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterRequest)
  })
_sym_db.RegisterMessage(UpdateClusterRequest)

UpdateClusterResponse = _reflection.GeneratedProtocolMessageType('UpdateClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterResponse)
  })
_sym_db.RegisterMessage(UpdateClusterResponse)

UpdateClusterStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERSTATUSREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusRequest)
  })
_sym_db.RegisterMessage(UpdateClusterStatusRequest)

UpdateClusterStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateClusterStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERSTATUSRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateClusterStatusResponse)
  })
_sym_db.RegisterMessage(UpdateClusterStatusResponse)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterRequest)
  })
_sym_db.RegisterMessage(DeleteClusterRequest)

DeleteClusterResponse = _reflection.GeneratedProtocolMessageType('DeleteClusterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteClusterResponse)
  })
_sym_db.RegisterMessage(DeleteClusterResponse)

WatchClustersRequest = _reflection.GeneratedProtocolMessageType('WatchClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHCLUSTERSREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersRequest)
  })
_sym_db.RegisterMessage(WatchClustersRequest)

WatchClustersResponse = _reflection.GeneratedProtocolMessageType('WatchClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHCLUSTERSRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchClustersResponse)
  })
_sym_db.RegisterMessage(WatchClustersResponse)

QueryClusterLogsRequest = _reflection.GeneratedProtocolMessageType('QueryClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCLUSTERLOGSREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsRequest)
  })
_sym_db.RegisterMessage(QueryClusterLogsRequest)

QueryClusterLogsResponse = _reflection.GeneratedProtocolMessageType('QueryClusterLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCLUSTERLOGSRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.QueryClusterLogsResponse)
  })
_sym_db.RegisterMessage(QueryClusterLogsResponse)

TailClusterLogsRequest = _reflection.GeneratedProtocolMessageType('TailClusterLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TAILCLUSTERLOGSREQUEST,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsRequest)
  })
_sym_db.RegisterMessage(TailClusterLogsRequest)

TailClusterLogsResponse = _reflection.GeneratedProtocolMessageType('TailClusterLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TAILCLUSTERLOGSRESPONSE,
  '__module__' : 'grid.v1.cluster_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.TailClusterLogsResponse)
  })
_sym_db.RegisterMessage(TailClusterLogsResponse)


DESCRIPTOR._options = None

_CLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='ClusterService',
  full_name='grid.v1.ClusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2688,
  serialized_end=3459,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateCluster',
    full_name='grid.v1.ClusterService.CreateCluster',
    index=0,
    containing_service=None,
    input_type=_CREATECLUSTERREQUEST,
    output_type=_CREATECLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCluster',
    full_name='grid.v1.ClusterService.GetCluster',
    index=1,
    containing_service=None,
    input_type=_GETCLUSTERREQUEST,
    output_type=_GETCLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListClusters',
    full_name='grid.v1.ClusterService.ListClusters',
    index=2,
    containing_service=None,
    input_type=_LISTCLUSTERSREQUEST,
    output_type=_LISTCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCluster',
    full_name='grid.v1.ClusterService.UpdateCluster',
    index=3,
    containing_service=None,
    input_type=_UPDATECLUSTERREQUEST,
    output_type=_UPDATECLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateClusterStatus',
    full_name='grid.v1.ClusterService.UpdateClusterStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATECLUSTERSTATUSREQUEST,
    output_type=_UPDATECLUSTERSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCluster',
    full_name='grid.v1.ClusterService.DeleteCluster',
    index=5,
    containing_service=None,
    input_type=_DELETECLUSTERREQUEST,
    output_type=_DELETECLUSTERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchClusters',
    full_name='grid.v1.ClusterService.WatchClusters',
    index=6,
    containing_service=None,
    input_type=_WATCHCLUSTERSREQUEST,
    output_type=_WATCHCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryClusterLogs',
    full_name='grid.v1.ClusterService.QueryClusterLogs',
    index=7,
    containing_service=None,
    input_type=_QUERYCLUSTERLOGSREQUEST,
    output_type=_QUERYCLUSTERLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TailClusterLogs',
    full_name='grid.v1.ClusterService.TailClusterLogs',
    index=8,
    containing_service=None,
    input_type=_TAILCLUSTERLOGSREQUEST,
    output_type=_TAILCLUSTERLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLUSTERSERVICE)

DESCRIPTOR.services_by_name['ClusterService'] = _CLUSTERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import suspicious_activity_pb2 as grid_dot_v1_dot_suspicious__activity__pb2


class SuspiciousActivityServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ReportSuspiciousActivity = channel.unary_unary(
        '/grid.v1.SuspiciousActivityService/ReportSuspiciousActivity',
        request_serializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityResponse.FromString,
        )


class SuspiciousActivityServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ReportSuspiciousActivity(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SuspiciousActivityServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ReportSuspiciousActivity': grpc.unary_unary_rpc_method_handler(
          servicer.ReportSuspiciousActivity,
          request_deserializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityRequest.FromString,
          response_serializer=grid_dot_v1_dot_suspicious__activity__pb2.ReportSuspiciousActivityResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.SuspiciousActivityService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Test the hyperparameters module.
#
# Attribution
# -----------
#
# This code has been adapted from the scikit-learn project. Details of original source
# material and how to access are provided below:
#
# - Repository:    https://github.com/scikit-learn/scikit-learn
# - Commit:        ed3642014be412b0bda13d1ec756baeabb0dcbfe
# - File Path:     sklearn/model_selection/tests/test_search.py
# - License:       BSD 3 Clause
# - Access Date:   11 July 2021
# - Adapted By:    Richard Izzo (rlizzo)
# - License Text:  Please refer to NOTICE file in this repository for full
#                  text of original source license.
#
from collections.abc import Iterable, Sized
from functools import partial
from itertools import chain, product

import pytest

scipy_stats = pytest.importorskip("scipy.stats")

from grid.sdk.sweeps.grid_search_strategy import ParameterGrid, ParameterSampler


def assert_grid_iter_equals_getitem(grid):
    assert list(grid) == [grid[i] for i in range(len(grid))]


@pytest.mark.parametrize("klass", [ParameterGrid, partial(ParameterSampler, n_iter=10)])
@pytest.mark.parametrize(
    "input, error_type, error_message",
    [
        (0, TypeError, r"Parameter .* is not a dict or a list \(0\)"),
        ([{
            "foo": [0]
        }, 0], TypeError, r"Parameter .* is not a dict \(0\)"),
        (
            {
                "foo": 0
            },
            TypeError,
            "Parameter.* value is not iterable .*"
            r"\(key='foo', value=0\)",
        ),
    ],
)
def test_validate_parameter_input(klass, input, error_type, error_message):
    with pytest.raises(error_type, match=error_message):
        klass(input)


def test_parameter_grid():

    # Test basic properties of ParameterGrid.
    params1 = {"foo": [1, 2, 3]}
    grid1 = ParameterGrid(params1)
    assert isinstance(grid1, Iterable)
    assert isinstance(grid1, Sized)
    assert len(grid1) == 3
    assert_grid_iter_equals_getitem(grid1)

    params2 = {"foo": [4, 2], "bar": ["ham", "spam", "eggs"]}
    grid2 = ParameterGrid(params2)
    assert len(grid2) == 6

    # loop to assert we can iterate over the grid multiple times
    for i in range(2):
        # tuple + chain transforms {"a": 1, "b": 2} to ("a", 1, "b", 2)
        points = set(tuple(chain(*(sorted(p.items())))) for p in grid2)
        assert points == set(("bar", x, "foo", y) for x, y in product(params2["bar"], params2["foo"]))
    assert_grid_iter_equals_getitem(grid2)

    # Special case: empty grid (useful to get default estimator settings)
    empty = ParameterGrid({})
    assert len(empty) == 1
    assert list(empty) == [{}]
    assert_grid_iter_equals_getitem(empty)
    with pytest.raises(IndexError):
        _ = empty[1]

    has_empty = ParameterGrid([{"C": [1, 10]}, {}, {"C": [0.5]}])
    assert len(has_empty) == 4
    assert list(has_empty) == [{"C": 1}, {"C": 10}, {}, {"C": 0.5}]
    assert_grid_iter_equals_getitem(has_empty)


def test_param_sampler():
    # test basic properties of param sampler
    param_distributions = {"kernel": ["rbf", "linear"], "C": scipy_stats.uniform(0, 1)}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=10, random_state=0)
    samples = [x for x in sampler]
    assert len(samples) == 10
    for sample in samples:
        assert sample["kernel"] in ["rbf", "linear"]
        assert 0 <= sample["C"] <= 1

    # test that repeated calls yield identical parameters
    param_distributions = {"C": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=3, random_state=0)
    assert [x for x in sampler] == [x for x in sampler]

    param_distributions = {"C": scipy_stats.uniform(0, 1)}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=10, random_state=0)
    assert [x for x in sampler] == [x for x in sampler]


def test_parameters_sampler_replacement():
    # raise warning if n_iter is bigger than total parameter space
    params = [
        {
            "first": [0, 1],
            "second": ["a", "b", "c"]
        },
        {
            "third": ["two", "values"]
        },
    ]
    sampler = ParameterSampler(params, n_iter=9)
    n_iter = 9
    grid_size = 8
    expected_warning = (
        "The total space of parameters %d is smaller "
        "than n_iter=%d. Running %d iterations. For "
        "exhaustive searches, use GridSearchCV." % (grid_size, n_iter, grid_size)
    )
    with pytest.warns(UserWarning, match=expected_warning):
        list(sampler)

    # degenerates to GridSearchCV if n_iter the same as grid_size
    sampler = ParameterSampler(params, n_iter=8)
    samples = list(sampler)
    assert len(samples) == 8
    for values in ParameterGrid(params):
        assert values in samples
    assert len(ParameterSampler(params, n_iter=1000)) == 8

    # test sampling without replacement in a large grid
    params = {"a": range(10), "b": range(10), "c": range(10)}
    sampler = ParameterSampler(params, n_iter=99, random_state=42)
    samples = list(sampler)
    assert len(samples) == 99
    hashable_samples = ["a%db%dc%d" % (p["a"], p["b"], p["c"]) for p in samples]
    assert len(set(hashable_samples)) == 99

    # doesn't go into infinite loops
    params_distribution = {"first": scipy_stats.bernoulli(0.5), "second": ["a", "b", "c"]}
    sampler = ParameterSampler(params_distribution, n_iter=7)
    samples = list(sampler)
    assert len(samples) == 7



import asyncio

import click
from google.protobuf.json_format import MessageToJson, Parse
from grpc.aio import AioRpcError

from grid.cli import rich_click
from grid.cli.client import Grid
from grid.protos.grid.v1.cluster_pb2 import Cluster
from grid.protos.grid.v1.cluster_service_pb2 import (
    GetClusterRequest,
    GetClusterResponse,
    UpdateClusterRequest,
    UpdateClusterResponse,
)
from grid.protos.grid.v1.cluster_service_pb2_grpc import ClusterServiceStub


@rich_click.group()
def edit() -> None:
    """Edits a resource"""
    pass


@edit.command()
@rich_click.argument('cluster', type=str)
def cluster(cluster: str):
    """Edit existing cluster"""
    async def f():
        async with Grid.grpc_channel() as conn:
            cluster_service = ClusterServiceStub(conn)
            resp: GetClusterResponse = await cluster_service.GetCluster(GetClusterRequest(id=cluster), )
            cl = resp.cluster
            before = MessageToJson(
                cl,
                including_default_value_fields=True,
            )
            after = click.edit(before)
            if after is None or after == before:
                click.echo("cluster unchanged")
                return
            cl = Cluster()
            Parse(
                text=after,
                message=cl,
            )
            resp: UpdateClusterResponse = await cluster_service.UpdateCluster(UpdateClusterRequest(cluster=cl))
            click.echo(f"{resp.cluster}")

    try:
        asyncio.run(f())
    except AioRpcError as e:
        raise click.ClickException(f"cluster {cluster}: {e.details()}")



import arrow
import click


def arrow_time_callback(_ctx, _param, value, arw_now=arrow.utcnow()) -> arrow.Arrow:
    try:
        return arw_now.dehumanize(value)
    except:
        pass
    try:
        return arrow.get(value)
    except:
        pass
    raise click.ClickException(f"cannot parse time {value}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/suspicious_activity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/suspicious_activity.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!grid/v1/suspicious_activity.proto\x12\x07grid.v1\x1a\x13grid/v1/event.proto\"\xfc\x01\n\x1fReportSuspiciousActivityRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails\x12:\n\rresource_type\x18\x06 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x07 \x01(\tR\nresourceId\"\"\n ReportSuspiciousActivityResponse2\x8c\x01\n\x19SuspiciousActivityService\x12o\n\x18ReportSuspiciousActivity\x12(.grid.v1.ReportSuspiciousActivityRequest\x1a).grid.v1.ReportSuspiciousActivityResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_event__pb2.DESCRIPTOR,])




_REPORTSUSPICIOUSACTIVITYREQUEST = _descriptor.Descriptor(
  name='ReportSuspiciousActivityRequest',
  full_name='grid.v1.ReportSuspiciousActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ReportSuspiciousActivityRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ReportSuspiciousActivityRequest.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.ReportSuspiciousActivityRequest.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='grid.v1.ReportSuspiciousActivityRequest.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reason', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='grid.v1.ReportSuspiciousActivityRequest.details', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='details', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='grid.v1.ReportSuspiciousActivityRequest.resource_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='grid.v1.ReportSuspiciousActivityRequest.resource_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=320,
)


_REPORTSUSPICIOUSACTIVITYRESPONSE = _descriptor.Descriptor(
  name='ReportSuspiciousActivityResponse',
  full_name='grid.v1.ReportSuspiciousActivityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=356,
)

_REPORTSUSPICIOUSACTIVITYREQUEST.fields_by_name['resource_type'].enum_type = grid_dot_v1_dot_event__pb2._RESOURCETYPE
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityRequest'] = _REPORTSUSPICIOUSACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityResponse'] = _REPORTSUSPICIOUSACTIVITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportSuspiciousActivityRequest = _reflection.GeneratedProtocolMessageType('ReportSuspiciousActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPORTSUSPICIOUSACTIVITYREQUEST,
  '__module__' : 'grid.v1.suspicious_activity_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityRequest)
  })
_sym_db.RegisterMessage(ReportSuspiciousActivityRequest)

ReportSuspiciousActivityResponse = _reflection.GeneratedProtocolMessageType('ReportSuspiciousActivityResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPORTSUSPICIOUSACTIVITYRESPONSE,
  '__module__' : 'grid.v1.suspicious_activity_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityResponse)
  })
_sym_db.RegisterMessage(ReportSuspiciousActivityResponse)


DESCRIPTOR._options = None

_SUSPICIOUSACTIVITYSERVICE = _descriptor.ServiceDescriptor(
  name='SuspiciousActivityService',
  full_name='grid.v1.SuspiciousActivityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=359,
  serialized_end=499,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReportSuspiciousActivity',
    full_name='grid.v1.SuspiciousActivityService.ReportSuspiciousActivity',
    index=0,
    containing_service=None,
    input_type=_REPORTSUSPICIOUSACTIVITYREQUEST,
    output_type=_REPORTSUSPICIOUSACTIVITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUSPICIOUSACTIVITYSERVICE)

DESCRIPTOR.services_by_name['SuspiciousActivityService'] = _SUSPICIOUSACTIVITYSERVICE

# @@protoc_insertion_point(module_scope)



from grid.cli.commands.checks import WorkflowChecksMixin
from grid.cli.commands.credentials import CredentialsMixin
from grid.cli.commands.dependencies import DependencyMixin

__all__ = ['CredentialsMixin', 'WorkflowChecksMixin', 'DependencyMixin']



from typing import Optional

import click

from grid.cli import rich_click
from grid.cli.client import Grid


@click.option(
    '--global',
    'is_global',
    type=bool,
    is_flag=True,
    help='Fetch history from everyone in the team when flag is passed'
)
@rich_click.command()
def history(is_global: Optional[bool] = False) -> None:
    """View list of historic Runs."""
    client = Grid()
    client.history(is_global=is_global)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/logs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/logs.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12grid/v1/logs.proto\x12\x07grid.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd0\x01\n\x08LogEntry\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x35\n\x06labels\x18\x03 \x03(\x0b\x32\x1d.grid.v1.LogEntry.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa6\x02\n\x0fLogQueryRequest\x12\x43\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12?\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndTimestamp\x12\x14\n\x05limit\x18\x03 \x01(\x04R\x05limit\x12<\n\x06labels\x18\x04 \x03(\x0b\x32$.grid.v1.LogQueryRequest.LabelsEntryR\x06labels\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_LOGENTRY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='grid.v1.LogEntry.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.LogEntry.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.LogEntry.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=273,
)

_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='grid.v1.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='grid.v1.LogEntry.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='grid.v1.LogEntry.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='grid.v1.LogEntry.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='labels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGENTRY_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=273,
)


_LOGQUERYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='grid.v1.LogQueryRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grid.v1.LogQueryRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='grid.v1.LogQueryRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=273,
)

_LOGQUERYREQUEST = _descriptor.Descriptor(
  name='LogQueryRequest',
  full_name='grid.v1.LogQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.LogQueryRequest.start_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='grid.v1.LogQueryRequest.end_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.LogQueryRequest.limit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='grid.v1.LogQueryRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='labels', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGQUERYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=570,
)

_LOGENTRY_LABELSENTRY.containing_type = _LOGENTRY
_LOGENTRY.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGENTRY.fields_by_name['labels'].message_type = _LOGENTRY_LABELSENTRY
_LOGQUERYREQUEST_LABELSENTRY.containing_type = _LOGQUERYREQUEST
_LOGQUERYREQUEST.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGQUERYREQUEST.fields_by_name['end_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGQUERYREQUEST.fields_by_name['labels'].message_type = _LOGQUERYREQUEST_LABELSENTRY
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
DESCRIPTOR.message_types_by_name['LogQueryRequest'] = _LOGQUERYREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGENTRY_LABELSENTRY,
    '__module__' : 'grid.v1.logs_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.LogEntry.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'grid.v1.logs_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)
_sym_db.RegisterMessage(LogEntry.LabelsEntry)

LogQueryRequest = _reflection.GeneratedProtocolMessageType('LogQueryRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGQUERYREQUEST_LABELSENTRY,
    '__module__' : 'grid.v1.logs_pb2'
    # @@protoc_insertion_point(class_scope:grid.v1.LogQueryRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGQUERYREQUEST,
  '__module__' : 'grid.v1.logs_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.LogQueryRequest)
  })
_sym_db.RegisterMessage(LogQueryRequest)
_sym_db.RegisterMessage(LogQueryRequest.LabelsEntry)


DESCRIPTOR._options = None
_LOGENTRY_LABELSENTRY._options = None
_LOGQUERYREQUEST_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import user_pb2 as grid_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/user_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1agrid/v1/user_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x12grid/v1/user.proto\"6\n\x11\x43reateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12\x43reateUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\" \n\x0eGetUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"4\n\x0fGetUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"z\n\x10ListUsersRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\"\x88\x01\n\x11ListUsersResponse\x12!\n\x04user\x18\x01 \x03(\x0b\x32\r.grid.v1.UserR\x04user\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"6\n\x11UpdateUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12UpdateUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"<\n\x17UpdateUserStatusRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"=\n\x18UpdateUserStatusResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"6\n\x11\x44\x65leteUserRequest\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"7\n\x12\x44\x65leteUserResponse\x12!\n\x04user\x18\x01 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"T\n\x11WatchUsersRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"\x8a\x01\n\x12WatchUsersResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12!\n\x04user\x18\x03 \x01(\x0b\x32\r.grid.v1.UserR\x04user\"3\n\x18StopUserWorkloadsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"\x1b\n\x19StopUserWorkloadsResponse2\xec\x04\n\x0bUserService\x12G\n\nCreateUser\x12\x1a.grid.v1.CreateUserRequest\x1a\x1b.grid.v1.CreateUserResponse\"\x00\x12>\n\x07GetUser\x12\x17.grid.v1.GetUserRequest\x1a\x18.grid.v1.GetUserResponse\"\x00\x12\x44\n\tListUsers\x12\x19.grid.v1.ListUsersRequest\x1a\x1a.grid.v1.ListUsersResponse\"\x00\x12G\n\nUpdateUser\x12\x1a.grid.v1.UpdateUserRequest\x1a\x1b.grid.v1.UpdateUserResponse\"\x00\x12W\n\x10UpdateUserStatus\x12 .grid.v1.UpdateUserStatusRequest\x1a!.grid.v1.UpdateUserStatusResponse\x12G\n\nDeleteUser\x12\x1a.grid.v1.DeleteUserRequest\x1a\x1b.grid.v1.DeleteUserResponse\"\x00\x12G\n\nWatchUsers\x12\x1a.grid.v1.WatchUsersRequest\x1a\x1b.grid.v1.WatchUsersResponse0\x01\x12Z\n\x11StopUserWorkloads\x12!.grid.v1.StopUserWorkloadsRequest\x1a\".grid.v1.StopUserWorkloadsResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_user__pb2.DESCRIPTOR,])




_CREATEUSERREQUEST = _descriptor.Descriptor(
  name='CreateUserRequest',
  full_name='grid.v1.CreateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.CreateUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=188,
)


_CREATEUSERRESPONSE = _descriptor.Descriptor(
  name='CreateUserResponse',
  full_name='grid.v1.CreateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.CreateUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=245,
)


_GETUSERREQUEST = _descriptor.Descriptor(
  name='GetUserRequest',
  full_name='grid.v1.GetUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetUserRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=279,
)


_GETUSERRESPONSE = _descriptor.Descriptor(
  name='GetUserResponse',
  full_name='grid.v1.GetUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.GetUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=333,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='grid.v1.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListUsersRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListUsersRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListUsersRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=457,
)


_LISTUSERSRESPONSE = _descriptor.Descriptor(
  name='ListUsersResponse',
  full_name='grid.v1.ListUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.ListUsersResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListUsersResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListUsersResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=596,
)


_UPDATEUSERREQUEST = _descriptor.Descriptor(
  name='UpdateUserRequest',
  full_name='grid.v1.UpdateUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.UpdateUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=652,
)


_UPDATEUSERRESPONSE = _descriptor.Descriptor(
  name='UpdateUserResponse',
  full_name='grid.v1.UpdateUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.UpdateUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=709,
)


_UPDATEUSERSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateUserStatusRequest',
  full_name='grid.v1.UpdateUserStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.UpdateUserStatusRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=771,
)


_UPDATEUSERSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateUserStatusResponse',
  full_name='grid.v1.UpdateUserStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.UpdateUserStatusResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=834,
)


_DELETEUSERREQUEST = _descriptor.Descriptor(
  name='DeleteUserRequest',
  full_name='grid.v1.DeleteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.DeleteUserRequest.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=890,
)


_DELETEUSERRESPONSE = _descriptor.Descriptor(
  name='DeleteUserResponse',
  full_name='grid.v1.DeleteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.DeleteUserResponse.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=947,
)


_WATCHUSERSREQUEST = _descriptor.Descriptor(
  name='WatchUsersRequest',
  full_name='grid.v1.WatchUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchUsersRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchUsersRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1033,
)


_WATCHUSERSRESPONSE = _descriptor.Descriptor(
  name='WatchUsersResponse',
  full_name='grid.v1.WatchUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchUsersResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchUsersResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='grid.v1.WatchUsersResponse.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='user', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1174,
)


_STOPUSERWORKLOADSREQUEST = _descriptor.Descriptor(
  name='StopUserWorkloadsRequest',
  full_name='grid.v1.StopUserWorkloadsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.StopUserWorkloadsRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1227,
)


_STOPUSERWORKLOADSRESPONSE = _descriptor.Descriptor(
  name='StopUserWorkloadsResponse',
  full_name='grid.v1.StopUserWorkloadsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1256,
)

_CREATEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_CREATEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_GETUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_LISTUSERSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERSTATUSREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_UPDATEUSERSTATUSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_DELETEUSERREQUEST.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_DELETEUSERRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
_WATCHUSERSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHUSERSRESPONSE.fields_by_name['user'].message_type = grid_dot_v1_dot_user__pb2._USER
DESCRIPTOR.message_types_by_name['CreateUserRequest'] = _CREATEUSERREQUEST
DESCRIPTOR.message_types_by_name['CreateUserResponse'] = _CREATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['GetUserRequest'] = _GETUSERREQUEST
DESCRIPTOR.message_types_by_name['GetUserResponse'] = _GETUSERRESPONSE
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserRequest'] = _UPDATEUSERREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserResponse'] = _UPDATEUSERRESPONSE
DESCRIPTOR.message_types_by_name['UpdateUserStatusRequest'] = _UPDATEUSERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateUserStatusResponse'] = _UPDATEUSERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteUserRequest'] = _DELETEUSERREQUEST
DESCRIPTOR.message_types_by_name['DeleteUserResponse'] = _DELETEUSERRESPONSE
DESCRIPTOR.message_types_by_name['WatchUsersRequest'] = _WATCHUSERSREQUEST
DESCRIPTOR.message_types_by_name['WatchUsersResponse'] = _WATCHUSERSRESPONSE
DESCRIPTOR.message_types_by_name['StopUserWorkloadsRequest'] = _STOPUSERWORKLOADSREQUEST
DESCRIPTOR.message_types_by_name['StopUserWorkloadsResponse'] = _STOPUSERWORKLOADSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

CreateUserResponse = _reflection.GeneratedProtocolMessageType('CreateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateUserResponse)
  })
_sym_db.RegisterMessage(CreateUserResponse)

GetUserRequest = _reflection.GeneratedProtocolMessageType('GetUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetUserRequest)
  })
_sym_db.RegisterMessage(GetUserRequest)

GetUserResponse = _reflection.GeneratedProtocolMessageType('GetUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetUserResponse)
  })
_sym_db.RegisterMessage(GetUserResponse)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType('ListUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListUsersResponse)
  })
_sym_db.RegisterMessage(ListUsersResponse)

UpdateUserRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserRequest)
  })
_sym_db.RegisterMessage(UpdateUserRequest)

UpdateUserResponse = _reflection.GeneratedProtocolMessageType('UpdateUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserResponse)
  })
_sym_db.RegisterMessage(UpdateUserResponse)

UpdateUserStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateUserStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERSTATUSREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserStatusRequest)
  })
_sym_db.RegisterMessage(UpdateUserStatusRequest)

UpdateUserStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateUserStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERSTATUSRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateUserStatusResponse)
  })
_sym_db.RegisterMessage(UpdateUserStatusResponse)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

DeleteUserResponse = _reflection.GeneratedProtocolMessageType('DeleteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteUserResponse)
  })
_sym_db.RegisterMessage(DeleteUserResponse)

WatchUsersRequest = _reflection.GeneratedProtocolMessageType('WatchUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHUSERSREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchUsersRequest)
  })
_sym_db.RegisterMessage(WatchUsersRequest)

WatchUsersResponse = _reflection.GeneratedProtocolMessageType('WatchUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHUSERSRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchUsersResponse)
  })
_sym_db.RegisterMessage(WatchUsersResponse)

StopUserWorkloadsRequest = _reflection.GeneratedProtocolMessageType('StopUserWorkloadsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPUSERWORKLOADSREQUEST,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.StopUserWorkloadsRequest)
  })
_sym_db.RegisterMessage(StopUserWorkloadsRequest)

StopUserWorkloadsResponse = _reflection.GeneratedProtocolMessageType('StopUserWorkloadsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPUSERWORKLOADSRESPONSE,
  '__module__' : 'grid.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.StopUserWorkloadsResponse)
  })
_sym_db.RegisterMessage(StopUserWorkloadsResponse)


DESCRIPTOR._options = None

_USERSERVICE = _descriptor.ServiceDescriptor(
  name='UserService',
  full_name='grid.v1.UserService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1259,
  serialized_end=1879,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='grid.v1.UserService.CreateUser',
    index=0,
    containing_service=None,
    input_type=_CREATEUSERREQUEST,
    output_type=_CREATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUser',
    full_name='grid.v1.UserService.GetUser',
    index=1,
    containing_service=None,
    input_type=_GETUSERREQUEST,
    output_type=_GETUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='grid.v1.UserService.ListUsers',
    index=2,
    containing_service=None,
    input_type=_LISTUSERSREQUEST,
    output_type=_LISTUSERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUser',
    full_name='grid.v1.UserService.UpdateUser',
    index=3,
    containing_service=None,
    input_type=_UPDATEUSERREQUEST,
    output_type=_UPDATEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateUserStatus',
    full_name='grid.v1.UserService.UpdateUserStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATEUSERSTATUSREQUEST,
    output_type=_UPDATEUSERSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteUser',
    full_name='grid.v1.UserService.DeleteUser',
    index=5,
    containing_service=None,
    input_type=_DELETEUSERREQUEST,
    output_type=_DELETEUSERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchUsers',
    full_name='grid.v1.UserService.WatchUsers',
    index=6,
    containing_service=None,
    input_type=_WATCHUSERSREQUEST,
    output_type=_WATCHUSERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopUserWorkloads',
    full_name='grid.v1.UserService.StopUserWorkloads',
    index=7,
    containing_service=None,
    input_type=_STOPUSERWORKLOADSREQUEST,
    output_type=_STOPUSERWORKLOADSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERSERVICE)

DESCRIPTOR.services_by_name['UserService'] = _USERSERVICE

# @@protoc_insertion_point(module_scope)
